@@ -1,10 +1,10 @@
 from dataclasses import dataclass
-from typing import Any
+from typing import Any, Optional
 
 from commanderbot_lib.options.abc.cog_options import CogOptions
 
 
 @dataclass
 class FaqOptions(CogOptions):
-    database: Any = None
-    prefix: str = None
+    database: Optional[Any] = None
+    prefix: Optional[str] = None
